@@ -77,7 +77,7 @@
  *
  * @ingroup output_redirection
  */
-FILE * FOUT = NULL;
+// static FILE * FOUT = NULL;
 
 /** Current stream for error messages.
  *
@@ -87,7 +87,7 @@ FILE * FOUT = NULL;
  *
  * @ingroup output_redirection
  */
-FILE * FERR = NULL;
+// static FILE * FERR = NULL;
 
 
 #ifdef OVERKILL
@@ -98,6 +98,38 @@ static int   fout_stack_pos = -1;
 #endif
 
 
+typedef struct {
+   FILE * fout;
+   FILE * ferr;
+   DDCA_Output_Level output_level;
+   // bool   report_ddc_errors;    // unused, ddc error reporting left as global
+   DDCA_Error_Detail * error_detail;
+} Thread_Output_Settings;
+
+static Thread_Output_Settings *  get_thread_settings() {
+   static GPrivate per_thread_dests_key = G_PRIVATE_INIT(g_free);
+
+   Thread_Output_Settings *settings = g_private_get(&per_thread_dests_key);
+
+   // GThread * this_thread = g_thread_self();
+   // printf("(%s) this_thread=%p, settings=%p\n", __func__, this_thread, settings);
+
+   if (!settings) {
+      settings = g_new0(Thread_Output_Settings, 1);
+      settings->fout = stdout;
+      settings->ferr = stderr;
+      settings->output_level = DDCA_OL_NORMAL;
+      // settings->report_ddc_errors = false;    // redundant, but specified for documentation
+
+      g_private_set(&per_thread_dests_key, settings);
+   }
+
+   // printf("(%s) Returning: %p\n", __func__, settings);
+   return settings;
+}
+
+
+
 /** Initialize **stdout** and **stderr** redirection.
  *
  * Must be called during program initialization.
@@ -105,8 +137,10 @@ static int   fout_stack_pos = -1;
  * @ingroup output_redirection
  */
 void init_msg_control() {
-   FOUT = stdout;
-   FERR = stderr;
+   // FOUT = stdout;
+   // FERR = stderr;
+
+   // initialization now performed in get_thread_settings()
 }
 
 
@@ -115,7 +149,7 @@ void init_msg_control() {
 // To reset to STDOUT, use constant stdout in stdio.h  - NO - screws up rpt_util
 // problem:
 
-/** Redirect output that would normally go to **stdout**.
+/** Redirect output on the current thread that would normally go to **stdout**.
  *
  *  @param fout pointer to output stream
  *
@@ -124,7 +158,9 @@ void init_msg_control() {
 void set_fout(FILE * fout) {
    bool debug = false;
    DBGMSF(debug, "fout = %p", fout);
-   FOUT = fout;
+   Thread_Output_Settings * dests = get_thread_settings();
+   dests->fout = fout;
+   // FOUT = fout;
    rpt_change_output_dest(fout);
 }
 
@@ -132,7 +168,9 @@ void set_fout(FILE * fout) {
  * @ingroup output_redirection
  */
 void set_fout_to_default() {
-   FOUT = stdout;
+   // FOUT = stdout;
+   Thread_Output_Settings * dests = get_thread_settings();
+   dests->fout = stdout;
    rpt_change_output_dest(stdout);
 }
 
@@ -142,14 +180,30 @@ void set_fout_to_default() {
  * @ingroup output_redirection
  */
 void set_ferr(FILE * ferr) {
-   FERR = ferr;
+   // FERR = ferr;
+   Thread_Output_Settings * dests = get_thread_settings();
+   dests->ferr = ferr;
 }
 
 /** Redirect output that would normally go to **stderr** back to **stderr**.
  * @ingroup output_redirection
  */
 void set_ferr_to_default() {
-   FERR = stderr;
+   // FERR = stderr;
+   Thread_Output_Settings * dests = get_thread_settings();
+   dests->ferr = stderr;
+}
+
+FILE * fout() {
+   // return FOUT;
+   Thread_Output_Settings * dests = get_thread_settings();
+   return dests->fout;
+}
+
+FILE * ferr() {
+   // return FERR;
+   Thread_Output_Settings * dests = get_thread_settings();
+   return dests->ferr;
 }
 
 
@@ -348,7 +402,7 @@ print_simple_title_value(int    offset_start_to_title,
                          int    offset_title_start_to_value,
                          char * value)
 {
-   f0printf(FOUT, "%.*s%-*s%s\n",
+   f0printf(fout(), "%.*s%-*s%s\n",
             offset_start_to_title,"",
             offset_title_start_to_value, title,
             value);
@@ -364,7 +418,8 @@ print_simple_title_value(int    offset_start_to_title,
  * Functions and variables to manage and query output level settings.
  */
 
-static DDCA_Output_Level output_level;
+// static DDCA_Output_Level output_level;
+
 
 /** Gets the current output level.
  *
@@ -373,18 +428,25 @@ static DDCA_Output_Level output_level;
  * \ingroup msglevel
  */
 DDCA_Output_Level get_output_level() {
-   return output_level;
+   // return output_level;
+   Thread_Output_Settings * settings = get_thread_settings();
+   return settings->output_level;
 }
 
 /** Sets the output level.
  *
  * @param newval output level to set
+ * @return old output level
  *
  *  \ingroup msglevel
  */
-void set_output_level(DDCA_Output_Level newval) {
+DDCA_Output_Level set_output_level(DDCA_Output_Level newval) {
    // printf("(%s) newval=%s  \n", __func__, msgLevelName(newval) );
-   output_level = newval;
+   // output_level = newval;
+   Thread_Output_Settings * settings = get_thread_settings();
+   DDCA_Output_Level old_level = settings->output_level;
+   settings->output_level = newval;
+   return old_level;
 }
 
 /** Gets the printable name of an output level.
@@ -420,10 +482,11 @@ char * output_level_name(DDCA_Output_Level val) {
  */
 void show_output_level() {
    // printf("Output level:           %s\n", output_level_name(output_level));
+   Thread_Output_Settings * settings = get_thread_settings();
    print_simple_title_value(SHOW_REPORTING_TITLE_START,
                               "Output level: ",
                               SHOW_REPORTING_MIN_TITLE_SIZE,
-                              output_level_name(output_level));
+                              output_level_name(settings->output_level));
 }
 
 
@@ -676,8 +739,38 @@ bool report_freed_exceptions = false;
 // Report DDC data errors
 //
 
-// global variable - controls display of messages regarding DDC data errors
-bool report_ddc_errors = true;
+
+
+#ifdef PER_THREAD
+bool enable_report_ddc_errors(bool onoff) {
+   Thread_Output_Settings * dests = get_thread_settings();
+   bool old_val = dests->report_ddc_errors;
+   dests->report_ddc_errors = onoff;
+   return old_val;
+}
+
+bool is_report_ddc_errors_enabled() {
+   Thread_Output_Settings * dests = get_thread_settings();
+   bool old_val = dests->report_ddc_errors;
+   return old_val;
+}
+#else
+static bool report_ddc_errors = false;
+static GMutex report_ddc_errors_mutex;
+
+bool enable_report_ddc_errors(bool onoff) {
+   g_mutex_lock(&report_ddc_errors_mutex);
+   bool old_val = report_ddc_errors;
+   report_ddc_errors = onoff;
+   g_mutex_unlock(&report_ddc_errors_mutex);
+   return old_val;
+}
+
+bool is_report_ddc_errors_enabled() {
+   bool old_val = report_ddc_errors;
+   return old_val;
+}
+#endif
 
 
 /** Checks if DDC data errors are to be reported.  This is the case if any of the
@@ -697,7 +790,13 @@ bool report_ddc_errors = true;
  *  This function is normally wrapped in function **IS_REPORTING_DDC()**
  */
 bool is_reporting_ddc(Trace_Group trace_group, const char * filename, const char * funcname) {
-  bool result = (is_tracing(trace_group,filename, funcname) || report_ddc_errors);
+  bool result = (is_tracing(trace_group,filename, funcname) ||
+#ifdef PER_THREAD
+        is_report_ddc_errors_enabled()
+#else
+        report_ddc_errors
+#endif
+        );
   return result;
 }
 
@@ -724,16 +823,16 @@ bool ddcmsg(Trace_Group  trace_group,
 {
    bool result = false;
    bool debug_or_trace = is_tracing(trace_group, filename, funcname);
-   if (debug_or_trace || report_ddc_errors) {
+   if (debug_or_trace || is_report_ddc_errors_enabled()) {
       result = true;
       char buffer[200];
       va_list(args);
       va_start(args, format);
       vsnprintf(buffer, 200, format, args);
       if (debug_or_trace)
-         f0printf(FOUT, "(%s) DDC: %s\n", funcname, buffer);
+         f0printf(fout(), "(%s) DDC: %s\n", funcname, buffer);
       else
-         f0printf(FOUT, "DDC: %s\n", buffer);
+         f0printf(fout(), "DDC: %s\n", buffer);
       va_end(args);
    }
    return result;
@@ -741,7 +840,7 @@ bool ddcmsg(Trace_Group  trace_group,
 
 
 /** Tells whether DDC data errors are reported.
- *  Output is writtent to the current **FOUT** device.
+ *  Output is written to the current **FOUT** device.
  */
 void show_ddcmsg() {
    print_simple_title_value(SHOW_REPORTING_TITLE_START,
@@ -766,7 +865,7 @@ void show_reporting() {
    show_trace_groups();
    show_traced_functions();
    show_traced_files();
-   // f0puts("", FOUT);
+   // f0puts("", fout());
 }
 
 
@@ -801,7 +900,7 @@ void severemsg(
       va_start(args, format);
       vsnprintf(buffer, 200, format, args);
       snprintf(buf2, 250, "(%s) %s\n", funcname, buffer);
-      f0puts(buf2, FERR);
+      f0puts(buf2, ferr());
       va_end(args);
 }
 
@@ -865,7 +964,7 @@ bool dbgtrc(
          snprintf(buf2, bufsz+60, "[%s](%s) %s\n", formatted_elapsed_time(), funcname, buffer);
       else
          snprintf(buf2, bufsz+60, "(%s) %s\n", funcname, buffer);
-      f0puts(buf2, FOUT);    // no automatic terminating null
+      f0puts(buf2, fout());    // no automatic terminating null
       msg_emitted = true;
    }
 
@@ -926,7 +1025,7 @@ void report_ioctl_error(
       int          lineno)
 {
    int errsv = errno;
-   f0printf(FERR, "(%s) Error in ioctl(%s), errno=%s\n",
+   f0printf(ferr(), "(%s) Error in ioctl(%s), errno=%s\n",
            funcname, ioctl_name, linux_errno_desc(errnum) );
    errno = errsv;
 }
@@ -965,9 +1064,10 @@ void program_logic_error(
                       funcname, lineno, fn);
 
   // don't combine into 1 line, might be very long.  just output 2 lines:
-  f0puts(buf2,   FERR);
-  f0puts(buffer, FERR);
-  f0puts("\n",   FERR);
+  FILE * f = ferr();
+  f0puts(buf2,   f);
+  f0puts(buffer, f);
+  f0puts("\n",   f);
 }
 
 
@@ -1056,3 +1156,83 @@ void terminate_execution_on_error(
 }
 #endif
 
+
+
+void
+free_error_detail(DDCA_Error_Detail * ddca_erec)
+{
+   if (ddca_erec) {
+      assert(memcmp(ddca_erec->marker, DDCA_ERROR_DETAIL_MARKER, 4) == 0);
+      for (int ndx = 0; ndx < ddca_erec->cause_ct; ndx++) {
+         free_error_detail(ddca_erec->causes[ndx]);
+      }
+      free(ddca_erec->detail);
+      ddca_erec->marker[3] = 'x';
+      free(ddca_erec);
+   }
+}
+
+// static Thread_Output_Settings *  get_thread_settings()
+
+void free_thread_error_detail() {
+   Thread_Output_Settings * settings = get_thread_settings();
+   if (settings->error_detail) {
+      free_error_detail(settings->error_detail);
+      settings->error_detail = NULL;
+   }
+}
+
+
+DDCA_Error_Detail *
+error_info_to_ddca_detail(Error_Info * erec)
+{
+   DDCA_Error_Detail * result = NULL;
+   if (erec) {
+      // ???
+      int reqd_size = sizeof(DDCA_Error_Detail) + erec->cause_ct * sizeof(DDCA_Error_Detail*);
+      result = calloc(1, reqd_size);
+      memcpy(result->marker, DDCA_ERROR_DETAIL_MARKER, 4);
+      if (erec->detail)
+         result->detail = strdup(erec->detail);
+      for (int ndx = 0; ndx < erec->cause_ct; ndx++) {
+         DDCA_Error_Detail * cause = error_info_to_ddca_detail(erec->causes[ndx]);
+         result->causes[ndx] = cause;
+      }
+   }
+
+   return result;
+}
+
+DDCA_Error_Detail * get_thread_error_detail() {
+   Thread_Output_Settings * settings = get_thread_settings();
+   return settings->error_detail;
+}
+
+void save_thread_error_detail(DDCA_Error_Detail * error_detail) {
+   Thread_Output_Settings * settings = get_thread_settings();
+   if (settings->error_detail)
+      free_error_detail(settings->error_detail);
+   settings->error_detail = error_detail;
+}
+
+DDCA_Error_Detail *
+dup_error_detail(DDCA_Error_Detail * old) {
+   DDCA_Error_Detail * result = NULL;
+   if (old) {
+      // ???
+      int reqd_size = sizeof(DDCA_Error_Detail) + old->cause_ct * sizeof(DDCA_Error_Detail*);
+      result = calloc(1, reqd_size);
+      memcpy(result->marker, DDCA_ERROR_DETAIL_MARKER, 4);
+      if (old->detail)
+         result->detail = strdup(old->detail);
+      for (int ndx = 0; ndx < old->cause_ct; ndx++) {
+         DDCA_Error_Detail * cause = dup_error_detail(old->causes[ndx]);
+         result->causes[ndx] = cause;
+      }
+   }
+   return result;
+}
+
+
+
+
