@@ -35,6 +35,7 @@
 
 #include "util/error_info.h"
 #include "util/report_util.h"
+/** \endcond */
 
 #include "base/adl_errors.h"
 #include "base/ddc_errno.h"
@@ -55,7 +56,6 @@
 
 #include "vcp/parse_capabilities.h"
 
-#include "ddc/ddc_edid.h"
 #include "ddc/ddc_multi_part_io.h"
 #include "ddc/ddc_packet_io.h"
 #include "ddc/ddc_vcp.h"
@@ -119,7 +119,7 @@ check_valid_operation_by_feature_rec_and_version(
    assert(feature_flags);
    ushort rwflags   = operation_flags & DDCA_RW;
    ushort typeflags = operation_flags & (DDCA_NORMAL_TABLE | DDCA_CONT | DDCA_NC);
-   Public_Status_Code result = DDCL_INVALID_OPERATION;
+   Public_Status_Code result = DDCRC_INVALID_OPERATION;
    if ( (feature_flags & rwflags) && (feature_flags & typeflags) )
       result = 0;
    return result;
@@ -135,7 +135,7 @@ check_valid_operation_by_feature_id_and_dh(
    Public_Status_Code result = 0;
    VCP_Feature_Table_Entry * frec = vcp_find_feature_by_hexid(feature_id);
    if (!frec)
-      result = DDCL_UNKNOWN_FEATURE;
+      result = DDCRC_UNKNOWN_FEATURE;
    else {
       DDCA_MCCS_Version_Spec vcp_version = get_vcp_version_by_display_handle(dh);
       result = check_valid_operation_by_feature_rec_and_version(frec, vcp_version, operation_flags);
@@ -167,7 +167,7 @@ get_raw_value_for_feature_table_entry(
       Display_Handle *           dh,
       VCP_Feature_Table_Entry *  frec,
       bool                       ignore_unsupported,
-      DDCA_Single_Vcp_Value **   pvalrec,
+      Single_Vcp_Value **   pvalrec,
       FILE *                     msg_fh)
 {
    bool debug = false;
@@ -186,7 +186,7 @@ get_raw_value_for_feature_table_entry(
    bool is_table_feature = is_table_feature_by_display_handle(frec, dh);
    DDCA_Vcp_Value_Type feature_type = (is_table_feature) ? DDCA_TABLE_VCP_VALUE : DDCA_NON_TABLE_VCP_VALUE;
    DDCA_Output_Level output_level = get_output_level();
-   DDCA_Single_Vcp_Value * valrec = NULL;
+   Single_Vcp_Value * valrec = NULL;
    if (dh->dref->io_path.io_mode == DDCA_IO_USB) {
 #ifdef USE_USB
      psc = usb_get_vcp_value(
@@ -201,7 +201,7 @@ get_raw_value_for_feature_table_entry(
 #endif
    }
    else {
-      ddc_excp = get_vcp_value(
+      ddc_excp = ddc_get_vcp_value(
               dh,
               feature_code,
               feature_type,
@@ -214,7 +214,7 @@ get_raw_value_for_feature_table_entry(
    case 0:
       break;
 
-   case DDCRC_INVALID_DATA:
+   case DDCRC_DDC_DATA:           // was DDCRC_INVALID_DATA
       if (output_level >= DDCA_OL_NORMAL)
          f0printf(msg_fh, FMT_CODE_NAME_DETAIL_W_NL,
                          feature_code, feature_name, "Invalid response");
@@ -267,7 +267,7 @@ get_raw_value_for_feature_table_entry(
    DBGTRC(debug, TRACE_GROUP, "Done.  Returning: %s, *pvalrec=%p", psc_desc(psc), *pvalrec);
    assert( (psc == 0 && *pvalrec) || (psc != 0 && !*pvalrec) );
    if (*pvalrec && (debug || IS_TRACING())) {
-      dbgrpt_ddca_single_vcp_value(*pvalrec, 1);
+      dbgrpt_single_vcp_value(*pvalrec, 1);
    }
    if (ddc_excp) {
 #ifdef OLD
@@ -314,7 +314,7 @@ collect_raw_feature_set_values(
    for (ndx=0; ndx< features_ct; ndx++) {
       VCP_Feature_Table_Entry * entry = get_feature_set_entry(feature_set, ndx);
       DBGMSF(debug,"ndx=%d, feature = 0x%02x", ndx, entry->code);
-      DDCA_Single_Vcp_Value *    pvalrec;
+      Single_Vcp_Value *    pvalrec;
       Public_Status_Code cur_status_code =
        get_raw_value_for_feature_table_entry(
          dh,
@@ -367,7 +367,11 @@ collect_raw_subset_values(
    DBGMSF(debug, "Starting.  subset=%d  dh=%s", subset, dh_repr(dh) );
    DDCA_MCCS_Version_Spec vcp_version = get_vcp_version_by_display_handle(dh);
    // DBGMSG("VCP version = %d.%d", vcp_version.major, vcp_version.minor);
-   VCP_Feature_Set feature_set = create_feature_set(subset, vcp_version);
+   VCP_Feature_Set feature_set = create_feature_set(
+                                     subset,
+                                     vcp_version,
+                                     FSF_NOTABLE);
+                                //   false);      // exclude_table_features
    if (debug)
       report_feature_set(feature_set, 0);
 
@@ -384,20 +388,39 @@ collect_raw_subset_values(
 // Get formatted feature values
 //
 
+/** Queries the monitor for a VCP feature value, and returns
+ *  a formatted interpretation of the value.
+ *
+ * \param  dh         handle for open display
+ * \param  vcp_entry  feature table entry
+ * \param  suppress_unsupported
+ *                    if true, do not report unsupported features
+ * \param  prefix_value_with_feature_code
+ *                    include feature code in formatted value
+ * \param  pformatted_value
+ *                    where to return pointer to formatted value
+ * \param msg_fh      where to write extended messages for verbose
+ *                    value retrieval, etc.
+ * \return status code
+ *
+ * \remark
+ * This function is a kitchen sink of functionality, extracted from
+ * earlier code.  It needs refactoring.
+ */
 Public_Status_Code
 get_formatted_value_for_feature_table_entry(
       Display_Handle *           dh,
       VCP_Feature_Table_Entry *  vcp_entry,
       bool                       suppress_unsupported,
       bool                       prefix_value_with_feature_code,
-      char **                    pformatted_value,
+      char **                    formatted_value_loc,
       FILE *                     msg_fh)
 {
    bool debug = false;
    DBGTRC(debug, TRACE_GROUP, "Starting. suppress_unsupported=%s", bool_repr(suppress_unsupported));
 
    Public_Status_Code psc = 0;
-   *pformatted_value = NULL;
+   *formatted_value_loc = NULL;
 
    DDCA_MCCS_Version_Spec vspec = get_vcp_version_by_display_handle(dh);
    Byte feature_code = vcp_entry->code;
@@ -412,7 +435,7 @@ get_formatted_value_for_feature_table_entry(
                             feature_name);
    }
 
-   DDCA_Single_Vcp_Value *    pvalrec = NULL;
+   Single_Vcp_Value *    pvalrec = NULL;
 
    // bool ignore_unsupported = !(output_level >= DDCA_OL_NORMAL && !suppress_unsupported);
    bool ignore_unsupported = suppress_unsupported;
@@ -446,14 +469,14 @@ get_formatted_value_for_feature_table_entry(
             hexstring2(pvalrec->val.t.bytes, bytect, &space, false /* upper case */, hexbuf, hexbufsize);
             char * formatted = calloc(hexbufsize + 20, sizeof(char));
             snprintf(formatted, hexbufsize+20, "VCP %02X T x%s\n", feature_code, hexbuf);
-            *pformatted_value = formatted;
+            *formatted_value_loc = formatted;
             free(hexbuf);
          }
          else {                                // OL_PROGRAM, not table feature
             DDCA_Version_Feature_Flags vflags =
                get_version_sensitive_feature_flags(vcp_entry, vspec);
             char buf[200];
-            assert(vflags & (DDCA_CONT | DDCA_SIMPLE_NC | DDCA_COMPLEX_NC));
+            assert(vflags & (DDCA_CONT | DDCA_SIMPLE_NC | DDCA_COMPLEX_NC | DDCA_NC_CONT));
             if (vflags & DDCA_CONT) {
                snprintf(buf, 200, "VCP %02X C %d %d",
                                   vcp_entry->code,
@@ -464,7 +487,7 @@ get_formatted_value_for_feature_table_entry(
                                    vcp_entry->code, pvalrec->val.nc.sl);
             }
             else {
-               assert(vflags & DDCA_COMPLEX_NC);
+               assert(vflags & (DDCA_COMPLEX_NC|DDCA_NC_CONT));
                snprintf(buf, 200, "VCP %02X CNC x%02x x%02x x%02x x%02x",
                                   vcp_entry->code,
                                   pvalrec->val.nc.mh,
@@ -473,8 +496,7 @@ get_formatted_value_for_feature_table_entry(
                                   pvalrec->val.nc.sl
                                   );
             }
-
-            *pformatted_value = strdup(buf);
+            *formatted_value_loc = strdup(buf);
          }
       }
 
@@ -497,14 +519,14 @@ get_formatted_value_for_feature_table_entry(
 
          if (ok) {
             if (prefix_value_with_feature_code) {
-               *pformatted_value = calloc(1, strlen(formatted_data) + 50);
-               snprintf(*pformatted_value, strlen(formatted_data) + 49,
+               *formatted_value_loc = calloc(1, strlen(formatted_data) + 50);
+               snprintf(*formatted_value_loc, strlen(formatted_data) + 49,
                         FMT_CODE_NAME_DETAIL_WO_NL,
                         feature_code, feature_name, formatted_data);
                free(formatted_data);
             }
             else {
-                *pformatted_value = formatted_data;
+                *formatted_value_loc = formatted_data;
              }
          }
       }         // normal (non OL_PROGRAM) output
@@ -520,10 +542,9 @@ get_formatted_value_for_feature_table_entry(
    if (pvalrec)
       free_single_vcp_value(pvalrec);
 
-   // TRCMSGTG(tg, "Done.  Returning: %s, *pformatted_value=|%s|", gsc_desc(gsc), *pformatted_value);
    DBGTRC(debug, TRACE_GROUP,
-          "Done.  Returning: %s, *pformatted_value=|%s|",
-          psc_desc(psc), *pformatted_value);
+          "Done.  Returning: %s, *formatted_value_loc=|%s|",
+          psc_desc(psc), formatted_value_loc);
    return psc;
 }
 
@@ -532,8 +553,7 @@ Public_Status_Code
 show_feature_set_values(
       Display_Handle *      dh,
       VCP_Feature_Set       feature_set,
-      GPtrArray *           collector,     // if null, write to FOUT
- //      bool                  force_show_unsupported,  // deprecated
+      GPtrArray *           collector,     // if null, write to current stdout device
       Feature_Set_Flags     flags,
       Byte_Value_Array      features_seen)     // if non-null, collect list of features seen
 {
@@ -543,6 +563,8 @@ show_feature_set_values(
    DBGMSF(debug, "Starting.  flags=%s, collector=%p", s0, collector);
    free(s0);
 
+   FILE * outf = fout();
+
    VCP_Feature_Subset subset_id = get_feature_set_subset_id(feature_set);
    DDCA_Output_Level output_level = get_output_level();
    bool show_unsupported = false;
@@ -555,7 +577,7 @@ show_feature_set_values(
 
    DDCA_MCCS_Version_Spec vcp_version = get_vcp_version_by_display_handle(dh);
    bool prefix_value_with_feature_code = true;    // TO FIX
-   FILE * msg_fh = FOUT;                        // TO FIX
+   FILE * msg_fh = outf;                        // TO FIX
    int features_ct = get_feature_set_size(feature_set);
    DBGMSF(debug, "features_ct=%d", features_ct);
    int ndx;
@@ -568,18 +590,20 @@ show_feature_set_values(
             char * feature_name =  get_version_sensitive_feature_name(entry, vcp_version);
             DDCA_Version_Feature_Flags vflags = get_version_sensitive_feature_flags(entry, vcp_version);
             char * msg = (vflags & DDCA_DEPRECATED) ? "Deprecated" : "Write-only feature";
-            f0printf(FOUT, FMT_CODE_NAME_DETAIL_W_NL,
+            f0printf(outf, FMT_CODE_NAME_DETAIL_W_NL,
                           entry->code, feature_name, msg);
          }
       }
       else {
          bool skip_feature = false;
+#ifdef NO
          if (subset_id != VCP_SUBSET_SINGLE_FEATURE &&
              is_feature_table_by_vcp_version(entry, vcp_version) &&
              (flags & FSF_NOTABLE) )
          {
             skip_feature = true;
          }
+#endif
          if (!skip_feature) {
 
             char * formatted_value = NULL;
@@ -596,7 +620,7 @@ show_feature_set_values(
                if (collector)
                   g_ptr_array_add(collector, formatted_value);
                else
-                  f0printf(FOUT, "%s\n", formatted_value);
+                  f0printf(outf, "%s\n", formatted_value);
                free(formatted_value);
                if (features_seen)
                   bbf_set(features_seen, entry->code);  // note that feature was read
@@ -646,8 +670,8 @@ bool hack42(VCP_Feature_Table_Entry * ventry) {
  * Arguments:
  *    dh         display handle for open display
  *    subset     feature subset id
- *    collector  accumulates output    // if null, write to FOUT
- *    force_show_unsupported
+ *    collector  accumulates output    // if null, write to current stdout device
+ *    flags      feature set flags
  *    features_seen   if non-null, collect ids of features that exist
  *
  * Returns:
@@ -658,7 +682,6 @@ show_vcp_values(
         Display_Handle *    dh,
         VCP_Feature_Subset  subset,
         GPtrArray *         collector,    // not used
-  //       bool                force_show_unsupported, // deprecated
         Feature_Set_Flags   flags,
         Byte_Bit_Flags      features_seen)
 {
@@ -672,7 +695,11 @@ show_vcp_values(
 
    DDCA_MCCS_Version_Spec vcp_version = get_vcp_version_by_display_handle(dh);
    // DBGMSG("VCP version = %d.%d", vcp_version.major, vcp_version.minor);
-   VCP_Feature_Set feature_set = create_feature_set(subset, vcp_version);
+   VCP_Feature_Set feature_set = create_feature_set(
+                                    subset,
+                                    vcp_version,
+                                    flags);
+                               //   flags & FSF_NOTABLE);
 #ifdef FUTURE
    Parsed_Capabilities * pcaps = NULL;   // TODO: HOW TO GET Parsed_Capabilities?, will only be set for probe/interrogate
    // special case, if scanning, don't try to do a table read of manufacturer specific
