@@ -66,6 +66,7 @@
  *    could not be retrieved (pre MCCS v2)
  */
 DDCA_MCCS_Version_Spec get_vcp_version_by_display_handle(Display_Handle * dh) {
+   assert(dh);
    bool debug = false;
    // TMI
    DBGMSF(debug, "Starting. dh=%s, dh->dref->vcp_version =  %d.%d, %s",
@@ -75,7 +76,7 @@ DDCA_MCCS_Version_Spec get_vcp_version_by_display_handle(Display_Handle * dh) {
          DBGMSG0("Starting.  vcp_version not set");
          dbgrpt_display_handle(dh, /*msg=*/ NULL, 1);
       }
-      dh->dref->vcp_version = VCP_SPEC_UNKNOWN;
+      dh->dref->vcp_version = DDCA_VSPEC_UNKNOWN;
 
       if (dh->dref->io_path.io_mode == DDCA_IO_USB) {
 #ifdef USE_USB
@@ -95,7 +96,7 @@ DDCA_MCCS_Version_Spec get_vcp_version_by_display_handle(Display_Handle * dh) {
 #endif
       }
       else {    // normal case, not USB
-         DDCA_Single_Vcp_Value * pvalrec;
+         Single_Vcp_Value * pvalrec;
 
          // verbose output is distracting since this function is called when
          // querying for other things
@@ -103,8 +104,7 @@ DDCA_MCCS_Version_Spec get_vcp_version_by_display_handle(Display_Handle * dh) {
          if (olev == DDCA_OL_VERBOSE)
             set_output_level(DDCA_OL_NORMAL);
          Public_Status_Code psc =  0;
-         Error_Info * ddc_excp = get_vcp_value(dh, 0xdf, DDCA_NON_TABLE_VCP_VALUE, &pvalrec);
-         // psc = (ddc_excp) ? ddc_excp->psc : 0;
+         Error_Info * ddc_excp = ddc_get_vcp_value(dh, 0xdf, DDCA_NON_TABLE_VCP_VALUE, &pvalrec);
          psc = ERRINFO_STATUS(ddc_excp);
          DBGMSF(debug, "get_vcp_value() returned %s", psc_desc(psc));
          if (debug && psc == DDCRC_RETRIES)
@@ -119,6 +119,7 @@ DDCA_MCCS_Version_Spec get_vcp_version_by_display_handle(Display_Handle * dh) {
                           dh->dref->vcp_version.major,
                           dh->dref->vcp_version.minor,
                           format_vspec(dh->dref->vcp_version) );
+            free_single_vcp_value(pvalrec);
          }
          else {
             // happens for pre MCCS v2 monitors
@@ -127,12 +128,8 @@ DDCA_MCCS_Version_Spec get_vcp_version_by_display_handle(Display_Handle * dh) {
       }
       DBGMSF(debug, "Non-cache lookup returning: %d.%d", dh->dref->vcp_version.major, dh->dref->vcp_version.minor);
    }
-   // DBGMSF(debug, "Returning: %d.%d", dh->dref->vcp_version.major, dh->dref->vcp_version.minor);
-   assert( !vcp_version_eq(dh->dref->vcp_version, VCP_SPEC_UNQUERIED) );
-   // if (debug) {
-   //    DBGMSG("Done.");
-   //    report_display_handle(dh, /*msg=*/ NULL, 1);
-   // }
+
+   assert( !vcp_version_eq(dh->dref->vcp_version, DDCA_VSPEC_UNQUERIED) );
    DBGMSF(debug, "Returning dh->dref->vcp_version = %d.%d, %s",
                  dh->dref->vcp_version.major, dh->dref->vcp_version.minor,
                  format_vspec(dh->dref->vcp_version));
@@ -153,6 +150,7 @@ DDCA_MCCS_Version_Spec get_vcp_version_by_display_handle(Display_Handle * dh) {
  *    could not be retrieved (pre MCCS v2)
  */
 DDCA_MCCS_Version_Spec get_vcp_version_by_display_ref(Display_Ref * dref) {
+   assert(dref);
    bool debug = false;
    DBGMSF(debug, "Starting. dref=%p, dref->vcp_version =  %d.%d",
                  dref, dref->vcp_version.major, dref->vcp_version.minor);
@@ -163,14 +161,14 @@ DDCA_MCCS_Version_Spec get_vcp_version_by_display_ref(Display_Ref * dref) {
    if (vcp_version_is_unqueried(dref->vcp_version)) {
       Display_Handle * dh = NULL;
       // no need to check return code since aborting if error
-      // shouuld never fail, since open already succeeded
+      // should never fail, since open already succeeded - but what if locked?
       Public_Status_Code psc = ddc_open_display(dref, CALLOPT_ERR_MSG, &dh);
       assert(psc == 0);
       dref->vcp_version = get_vcp_version_by_display_handle(dh);
       ddc_close_display(dh);
    }
 
-   assert( !vcp_version_eq(dref->vcp_version, VCP_SPEC_UNQUERIED) );
+   assert( !vcp_version_eq(dref->vcp_version, DDCA_VSPEC_UNQUERIED) );
    DBGMSF(debug, "Returning: %d.%d", dref->vcp_version.major, dref->vcp_version.minor);
    return dref->vcp_version;
 }
