@@ -101,7 +101,7 @@ usb_get_usage_value_by_report_type_and_ucode(
       // Problem: errno=22 (invalid argument) can mean the usage code is invalid,
       // i.e. invalid feature code, or another arg error which indicates a programming error
       // occasionally errno = 22 invalid argument - for Battery System Page: Run Time to Empty
-      if (-rc == EINVAL) {
+      if (rc == -EINVAL) {
          if (debug)
             REPORT_IOCTL_ERROR("HIDIOCGUSAGE", -rc);
          psc = DDCRC_DETERMINED_UNSUPPORTED;
@@ -556,7 +556,7 @@ Public_Status_Code usb_get_vcp_value(
        Display_Handle *          dh,
        Byte                      feature_code,
        DDCA_Vcp_Value_Type            call_type,
-       DDCA_Single_Vcp_Value **       pvalrec)
+       Single_Vcp_Value **       pvalrec)
 {
    bool debug = false;
    DBGTRC(debug, TRACE_GROUP, "Starting. Reading feature 0x%02x", feature_code);
@@ -567,7 +567,7 @@ Public_Status_Code usb_get_vcp_value(
    Buffer * buffer = NULL;
 #endif
    Parsed_Nontable_Vcp_Response * parsed_nontable_response = NULL;
-   DDCA_Single_Vcp_Value * valrec = NULL;
+   Single_Vcp_Value * valrec = NULL;
    switch (call_type) {
 
    case (DDCA_NON_TABLE_VCP_VALUE):
@@ -697,7 +697,7 @@ usb_set_nontable_vcp_value(
 Public_Status_Code
 usb_set_vcp_value(                               // changed from set_vcp_value()
       Display_Handle *   dh,
-      DDCA_Single_Vcp_Value * vrec)
+      Single_Vcp_Value * vrec)
 {
    Public_Status_Code psc = 0;
    if (vrec->value_type == DDCA_NON_TABLE_VCP_VALUE) {
@@ -706,7 +706,7 @@ usb_set_vcp_value(                               // changed from set_vcp_value()
    else {
       assert(vrec->value_type == DDCA_TABLE_VCP_VALUE);
       // gsc = usb_set_table_vcp_value(dh, vrec->opcode, vrec->val.t.bytes, vrec->val.t.bytect);
-      psc = DDCL_UNIMPLEMENTED;
+      psc = DDCRC_UNIMPLEMENTED;
    }
 
    return psc;
