@@ -1,7 +1,7 @@
 /* debug_util.h
  *
  * <copyright>
- * Copyright (C) 2016-2017 Sanford Rockowitz <rockowitz@minsoft.com>
+ * Copyright (C) 2016-2018 Sanford Rockowitz <rockowitz@minsoft.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -28,8 +28,17 @@
  * Functions for debugging
  */
 
+#include <assert.h>
 #include <glib-2.0/glib.h>
 
+#define ASSERT_WITH_BACKTRACE(_condition) \
+do { \
+   if ( !(_condition) ) {  \
+      show_backtrace(2);   \
+      assert(_condition);  \
+   }                       \
+} while(0)
+
 GPtrArray * get_backtrace(int stack_adjust);
 void show_backtrace(int stack_adjust);
 
