@@ -1,7 +1,7 @@
 /* string_util.c
  *
  * <copyright>
- * Copyright (C) 2014-2016 Sanford Rockowitz <rockowitz@minsoft.com>
+ * Copyright (C) 2014-2018 Sanford Rockowitz <rockowitz@minsoft.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -586,9 +586,14 @@ Null_Terminated_String_Array ntsa_join(
 }
 
 
-
-
-
+/** Searches a #Null_Terminated_String_Array for an entry that matches a given
+ *  value using a match function provided.
+ *
+ *  @param  string_array  null-terminated string array
+ *  @param  value         value to look for
+ *  @param  func          comparison function
+ *  @return index of first matching entry, -1 if not found
+ */
 int ntsa_findx(
       Null_Terminated_String_Array string_array,
       char *                       value,
@@ -611,12 +616,20 @@ int ntsa_findx(
 
 }
 
+
+/** Searches a #Null_Terminated_String_Array for an entry equal to a
+ *  specified value.
+ *
+ *  @param  string_array  null-terminated string array
+ *  @param  value         value to look for
+ *  @return index of first matching entry, -1 if not found
+ */
 int  ntsa_find(  Null_Terminated_String_Array string_array, char * value) {
    return ntsa_findx(string_array, value, streq);
 }
 
 
-/* Reports the contents of a Null_Terminated_String_Array.
+/* Reports the contents of a #Null_Terminated_String_Array.
  *
  * @param string_array null-terminated string array
  *
@@ -635,7 +648,7 @@ void ntsa_show(Null_Terminated_String_Array string_array) {
 }
 
 
-/** Converts a Null_Terminated_String_Array to a GPtrArray of pointers to strings.
+/** Converts a #Null_Terminated_String_Array to a GPtrArray of pointers to strings.
  * The underlying strings are referenced, not duplicated.
  *
  * @param  ntsa  null-terminated array of strings
@@ -679,7 +692,6 @@ g_ptr_array_to_ntsa(
 /** Converts an ASCII string to upper case.  The original string is converted in place.
  *
  * @param  s string to force to upper case
- *
  * @return converted string
  */
 char * strupper(char * s) {
@@ -696,7 +708,6 @@ char * strupper(char * s) {
 
 /** Creates an upper case copy of an ASCII string
  *
- * Arguments:
  * @param  s  string to copy
  * @return newly allocated string, NULL if s is NULL
  */
@@ -713,13 +724,13 @@ char * strdup_uc(const char* s) {
 /* Replaces all instances of a character in a string with a different character.
  * The original string is converted in place.
  *
- * Arguments:
- *   s   string to force to upper case
- *
- * Returns:
- *   s   converted string
+ * @param  s        string to modify
+ * @param  old_char character to replace
+ * @param  new_char replacement character
+ * @return **s**
  */
-char * str_replace_char(char * s, char old_char, char new_char) {
+char * str_replace_char(char * s, char old_char, char new_char)
+{
    if (s) {
       char * p = s;
       while (*p) {
@@ -731,13 +742,15 @@ char * str_replace_char(char * s, char old_char, char new_char) {
    return s;
 }
 
+
 /** Concatenates 2 strings into a newly allocated buffer.
  *
  * @param s1 first string
  * @param s2 second string
  * @return newly allocated string
  */
-char * strcat_new(char * s1, char * s2) {
+char * strcat_new(char * s1, char * s2)
+{
     assert(s1);
     assert(s2);
     char * result = malloc(strlen(s1) + strlen(s2) + 1);
@@ -749,13 +762,13 @@ char * strcat_new(char * s1, char * s2) {
 
 /** Converts a sequence of characters into a (null-terminated) string.
  *
- *  @param start   pointer to first character
- *  @param len     number of characters
- *
+ *  @param  start   pointer to first character
+ *  @param  len     number of characters
  *  @return newly allocated string,
  *          NULL if start was NULL (is this the most useful behavior?)
  */
-char * chars_to_string(const char * start, int len) {
+char * chars_to_string(const char * start, int len)
+{
    assert(len >= 0);
    char * strbuf = NULL;
    if (start) {
@@ -781,7 +794,8 @@ char * chars_to_string(const char * start, int len) {
  * Consider allowing the truncation maker, currently "..." to be
  * specified as a parameter.
  */
-bool sbuf_append(char * buf, int bufsz, char * sepstr, char * nextval) {
+bool sbuf_append(char * buf, int bufsz, char * sepstr, char * nextval)
+{
    assert(buf && (bufsz > 4) );   //avoid handling pathological case
    bool truncated = false;
    int seplen = (sepstr) ? strlen(sepstr) : 0;
@@ -828,7 +842,8 @@ bool sbuf_append(char * buf, int bufsz, char * sepstr, char * nextval) {
  * @remark
  * This function wraps system function strtol(), hiding the ugly details.
  */
-bool str_to_int(const char * sval, int * p_ival, int base) {
+bool str_to_int(const char * sval, int * p_ival, int base)
+{
    assert (base == 0 || base == 10 || base == 16);
    bool debug = false;
    if (debug)
@@ -855,62 +870,22 @@ bool str_to_int(const char * sval, int * p_ival, int base) {
    return ok;
 }
 
-#ifdef OLD
-/** Converts a string representing an integer to an integer value.
- *
- * @param sval   string representing an integer
- * @param p_ival address at which to store integer value
- * @return true if conversion succeeded, false if it failed
- *
- * \remark
- * If conversion fails, the value pointed to by **p_ival** is unchanged.
- * @remark
- * This function wraps system function strtol(), hiding the ugly details.
- */
-bool str_to_int_old(const char * sval, int * p_ival) {
-   bool debug = false;
-   if (debug)
-      printf("(%s) sval->|%s|\n", __func__, sval);
-
-   char * endptr;
-   bool ok = false;
-   if ( *sval != '\0') {
-      long result = strtol(sval, &endptr, 10);
-      // printf("(%s) sval=%p, endptr=%p, *endptr=|%c| (0x%02x), result=%ld\n",
-      //        __func__, sval, endptr, *endptr, *endptr, result);
-      if (*endptr == '\0') {
-         *p_ival = result;
-         ok = true;
-      }
-   }
-
-   if (debug) {
-      if (ok)
-        printf("(%s) sval=%s, Returning: %s, *ival = %d\n", __func__, sval, bool_repr(ok), *p_ival);
-      else
-        printf("(%s) sval=%s, Returning: %s\n", __func__, sval, bool_repr(ok));
-   }
-   return ok;
-}
-#endif
-
 
 //
 // Hex value conversion.
 //
 
-
 /** Converts a (null terminated) string of 2 hex characters to
  * its byte value.
  *
- * @param  s       pointer to hex string
- * @param  result  pointer to byte in which converted value will be returned
- *
- * @return true  if successful conversion,
- *         false if string does not consist of hex characters,
- *               or is not 2 characters in length.
+ * @param  s         pointer to hex string
+ * @param  result    pointer to byte in which converted value will be returned
+ * @retval **true**  successful conversion,
+ * @retval **false** string does not consist of hex characters,
+ *                    or is not 2 characters in length.
  */
-bool hhs_to_byte_in_buf(const char * s, Byte * result) {
+bool hhs_to_byte_in_buf(const char * s, Byte * result)
+{
    // printf("(%s) Starting s=%s, strlen(s)=%zd\n", __func__, s, strlen(s) );
    // consider changing to fail if len != 2, or perhaps len != 1,2
    //assert(strlen(s) == 2);
@@ -944,13 +919,13 @@ bool hhs_to_byte_in_buf(const char * s, Byte * result) {
  *  the value to begin with "0x" or "x", or end with "h".  The allowed
  *  prefix or suffix is case-insensitive.
  *
- *  @param  s       pointer to hex string
- *  @param  result  pointer to byte in which result will be returned
- *
- *  @return **true**  if successful conversion,
- *          **false** if not
+ *  @param  s         pointer to hex string
+ *  @param  result    pointer to byte in which result will be returned
+ *  @retval **true**  successful conversion,
+ *  @retval **false** conversion unsuccessful
  */
-bool any_one_byte_hex_string_to_byte_in_buf(const char * s, Byte * result) {
+bool any_one_byte_hex_string_to_byte_in_buf(const char * s, Byte * result)
+{
    // printf("(%s) s = |%s|\n", __func__, s);
    char * suc = strdup_uc(s);
    char * suc0 = suc;
@@ -970,13 +945,13 @@ bool any_one_byte_hex_string_to_byte_in_buf(const char * s, Byte * result) {
 /** Converts 2 hex characters to their corresponding byte value.
  *  The characters need not be null terminated.
  *
- *  @param p_hh      pointer to hex characters.
- *  @param converted pointer go byte in which converted value will be returned
- *
- *  @return true if successful conversion, false if s does not point
- *          to hex characters
+ *  @param  p_hh      pointer to hex characters.
+ *  @param  converted pointer go byte in which converted value will be returned
+ *  @retval **true**  successful conversion
+ *  @retval **false** **s** does not point to hex characters
  */
-bool hhc_to_byte_in_buf(const char * p_hh, Byte * converted) {
+bool hhc_to_byte_in_buf(const char * p_hh, Byte * converted)
+{
    // printf("(%s) Starting p_hh=%.2s   \n", __func__, hh );
    char hhs[3];
    hhs[0] = p_hh[0];
@@ -987,68 +962,18 @@ bool hhc_to_byte_in_buf(const char * p_hh, Byte * converted) {
 }
 
 
-#ifdef DEPRECATED
-/* Converts a (null terminated) string of 2 hex characters to
- * its byte value.
- *
- * Arguments:
- *   s   pointer to hex string
- *
- * Returns:
- *   byte value
- *
- * Execution terminates if invalid hex value.
- */
-Byte hhs_to_byte(char * s) {
-   // printf("(%s) Starting s=%s, strlen(s)=%d   \n", __func__, s, strlen(s) );
-   Byte converted;
-   if (!hhs_to_byte_in_buf(s, &converted)) {
-      // no way to properly signal failure, so terminate execution
-      // don't call a function such as program_logic_error() since this
-      // file should have no dependencies on any other program files.
-      fprintf(stderr, "Invalid hex value: %s", s);
-      // exit(1);   //  warnings in OBS re exit() in library
-      converted = 0x00;    // stick something in there, ugh
-   }
-   return converted;
-}
-#endif
-
-#ifdef DEPRECATED
-/* Converts 2 hex characters to a single byte.
- *
- * Arguments:
- *   hh    address of 2 hex characters, need not be null terminated
- *
- * Returns:
- *   byte value
- *
- * Execution terminates if invalid hex value.
- */
-Byte hhc_to_byte(char * hh) {
-   // printf("(%s) Starting hh=%.2s   \n", __func__, hh );
-   char hhs[3];
-   hhs[0] = hh[0];
-   // hhs[1] = cc[1];   // why does compiler complain?
-   hhs[1] = *(hh+1);
-   hhs[2] = '\0';
-   return hhs_to_byte(hhs);
-}
-#endif
-
-
 /** Converts a string of hex characters (null terminated) to an array of bytes.
  *
  *  @param   hhs     string of hex characters
  *  @param   pBa     address at which to return pointer to byte array
- *
  *  @retval  >= 0 number of bytes in array,
  *  @retval  -1   string could not be converted
  *
  * If successful, the byte array whose address is returned in pBa has
  * been malloc'd.  It is the responsibility of the caller to free it.
  */
-int hhs_to_byte_array(const char * hhs, Byte** pBa) {
+int hhs_to_byte_array(const char * hhs, Byte** pBa)
+{
    if ( strlen(hhs) % 2)     // if odd number of characters
       return -1;
    char xlate[] = "0123456789ABCDEF";
@@ -1081,34 +1006,18 @@ int hhs_to_byte_array(const char * hhs, Byte** pBa) {
    return bytect;
 }
 
-#ifdef DEPRECATED
-void test_one_hhs2Byte(char * hhs) {
-   printf("(%s) Starting.  hhs=%s  \n", __func__, hhs );
-   Byte b1 = hhs_to_byte(hhs);
-   printf("(%s) %s -> 0x%02x  \n", __func__, hhs, b1 );
-}
-
-
-void test_hhs_to_byte() {
-   printf("(%s) Startomg  \n", __func__ );
-   test_one_hhs2Byte("01");
-   test_one_hhs2Byte("ZZ");
-   // test_one_hhs2Byte("123");
-}
-#endif
-
 
 /** Converts a sequence of bytes to its representation as a string of hex characters.
  *
  *  @param  bytes     pointer to bytes
  *  @param  len       number of bytes
- *
  *  @return pointer to newly allocated hex string
  *
  * The value returned by this function has been malloc'd.   It is the
  * responsibility of the caller to free the memory.
  */
-char * hexstring(const unsigned char * bytes, int len) {
+char * hexstring(const unsigned char * bytes, int len)
+{
    int alloc_size = 3*len + 1;
    char* str_buf = malloc(alloc_size);
 
@@ -1136,7 +1045,6 @@ char * hexstring(const unsigned char * bytes, int len) {
  *                    if NULL, then a buffer will be allocated
  * @param   bufsz     size of buffer
  *                    if 0, then a buffer will be allocated
- *
  * @return  pointer to hex string
  *
  * If this function allocates a buffer, it is the responsibility of the caller
@@ -1194,100 +1102,6 @@ char * hexstring2(
 }
 
 
-#ifdef DEPRECATED
-// TODO: replace implementation of hexstring2_t() with call to hexstring3_t()
-
-/** Thread safe version of #hexstring2().
- *
- *  This function allocates a thread specific buffer in which the
- *  hexstring is built.  The buffer is valid until the next call
- *  of this function in the same thread.
- *
- * @param   bytes    pointer to bytes
- * @param   len      number of bytes
- * @param   sepstr   string to separate each 2 hex character pairs representing a byte,
- *                   if NULL then no separators will be inserted
- * @param   uppercase if true, use uppercase hex characters,
- *                    if false, use lower case hex characters
- *
- * @return  pointer to hex string
- *
- * Note that if the returned pointer is referenced after another call to
- * this function, the results are unpredictable.
- *
- * This function is intended to simplify formatting of diagnostic messages, since
- * the caller needn't be concerned with buffer size and allocation.
- */
-char * hexstring2_t_old(
-          const unsigned char * bytes,
-          int                   len,
-          const char *          sepstr,
-          bool                  uppercase)
-{
-   static GPrivate  hexstring_key = G_PRIVATE_INIT(g_free);
-
-   char * buf = g_private_get(&hexstring_key);
-   // GThread * this_thread = g_thread_self();
-   // printf("(%s) this_thread=%p, hexstring_key=%p, buf=%p\n",
-   //        __func__, this_thread, &hexstring_key, buf);
-
-   // TODO: Keep track of buffer size, only reallocate if buffer insufficiently large.
-   // But note that this function is only used for diagnostic messages, so performance
-   // gain is insignificant.
-
-   if (buf)
-      g_free(buf);
-
-   // printf("(%s) bytes=%p, len=%d, sepstr=|%s|, uppercase=%s\n", __func__,
-   //       bytes, len, sepstr, bool_repr(uppercase));
-   int sepsize = 0;
-   if (sepstr) {
-      sepsize = strlen(sepstr);
-   }
-   int required_size = 1;    // special case if len == 0
-   if (len > 0)
-      required_size =   2*len             // hex rep of bytes
-                       + (len-1)*sepsize   // for separators
-                       + 1;                // terminating null
-   // printf("(%s) required_size=%d\n", __func__, required_size);
-
-   buf = g_new(char, required_size);
-   // printf("(%s) Calling g_private_set()\n", __func__);
-   g_private_set(&hexstring_key, buf);
-
-   // hexstring2(bytes, len, sepstr, uppercase, buf, required_size);
-
-   char * pattern = (uppercase) ? "%02X" : "%02x";
-
-   int incr1 = 2 + sepsize;
-   if (len == 0)
-      *buf = '\0';
-   for (int i=0; i < len; i++) {
-      // printf("(%s) i=%d, buffer+i*incr1=%p\n", __func__, i, buffer+i*incr1);
-      sprintf(buf+i*incr1, pattern, bytes[i]);
-      if (i < (len-1) && sepstr)
-         strcat(buf, sepstr);
-   }
-   // printf("(%s) strlen(buffer) = %ld, required_size=%d   \n", __func__, strlen(buffer), required_size );
-   // printf("(%s)  buffer=|%s|\n", __func__, buffer );
-   assert(strlen(buf) == required_size-1);
-
-   return buf;
-}
-#endif
-
-#ifdef DEPRECATED
-char * hexstring2_t(
-          const unsigned char * bytes,
-          int                   len,
-          const char *          sepstr,
-          bool                  uppercase)
-{
-   return hexstring3_t(bytes, len, sepstr, 1, uppercase);
-}
-#endif
-
-
 /** Thread safe version of #hexstring2().
  *
  * This function allocates a thread specific buffer in which the hex string is built.
@@ -1300,7 +1114,6 @@ char * hexstring2_t(
  * @param   hunk_size separator string frequency
  * @param   uppercase if true, use uppercase hex characters,
  *                    if false, use lower case hex characters
- *
  * @return  pointer to hex string
  *
  * Note that if the returned pointer is referenced after another call to
@@ -1319,23 +1132,6 @@ char * hexstring3_t(
    static GPrivate  hexstring3_key = G_PRIVATE_INIT(g_free);
    static GPrivate  hexstring3_len_key = G_PRIVATE_INIT(g_free);
 
-#ifdef OLD
-   char * buf = g_private_get(&hexstring3_key);
-   int  * bufsz_ptr = g_private_get(&hexstring3_len_key);
-   GThread * this_thread = g_thread_self();
-   printf("(%s) this_thread=%p, hexstring3_key=%p, buf=%p, hexstring3_len_key=%p, bufsz_ptr=%p\n",
-          __func__, this_thread, &hexstring3_key, buf, &hexstring3_len_key, bufsz_ptr);
-   if (bufsz_ptr)
-      printf("(%s) *bufsz_ptr = %d\n", __func__, *bufsz_ptr);
-
-   // TODO: Keep track of buffer size, only reallocate if buffer insufficiently large.
-   // But note that this function is only used for diagnostic messages, so performance
-   // gain is insignificant.
-
-   // unnecessary if use g_private_replace() instead of g_private_set()
-   // if (buf)
-   //    g_free(buf);
-#endif
    // printf("(%s) bytes=%p, len=%d, sepstr=|%s|, uppercase=%s\n", __func__,
    //       bytes, len, sepstr, bool_repr(uppercase));
    if (hunk_size == 0)
@@ -1355,20 +1151,6 @@ char * hexstring3_t(
                        + 1;                // terminating null
    // printf("(%s) sepstr=|%s|, hunk_size=%d, required_size=%d\n", __func__, sepstr, hunk_size, required_size);
 
-#ifdef OLD
-   if ( !bufsz_ptr || *bufsz_ptr < required_size) {
-      buf = g_new(char, required_size);
-      // printf("(%s) Calling g_private_set()\n", __func__);
-      g_private_replace(&hexstring3_key, buf);
-
-
-      if (!bufsz_ptr) {
-         bufsz_ptr = g_new(int, 1);
-         g_private_set(&hexstring3_len_key, bufsz_ptr);
-      }
-      *bufsz_ptr = required_size;
-   }
-#endif
    char * buf = get_thread_dynamic_buffer(&hexstring3_key, &hexstring3_len_key, required_size);
    // char * buf = get_thread_private_buffer(&hexstring3_key, NULL, required_size);
 
@@ -1394,6 +1176,21 @@ char * hexstring3_t(
 }
 
 
+/** Thread safe version of #hexstring().
+ *
+ * This function allocates a thread specific buffer in which the hex string is built.
+ * The buffer is valid until the next call of this function in the same thread.
+ *
+ * @param   bytes    pointer to bytes
+ * @param   len      number of bytes
+ * @return  pointer to hex string
+ *
+ * Note that if the returned pointer is referenced after another call to
+ * this function, the results are unpredictable.
+ *
+ * This function is intended to simplify formatting of diagnostic messages, since
+ * the caller needn't be concerned with buffer size and allocation.
+ */
 char * hexstring_t(
           const unsigned char * bytes,
           int                   len)
@@ -1479,7 +1276,8 @@ void fhex_dump(FILE * fh, const Byte* data, int size)
  * @param   data     start of region to show
  * @param   size     length of region
  */
-void hex_dump(const Byte* data, int size) {
+void hex_dump(const Byte* data, int size)
+{
    fhex_dump(stdout, data, size);
 }
 
@@ -1492,7 +1290,8 @@ void hex_dump(const Byte* data, int size) {
  *
  *  @return result of underlying fputs(), or 0 if stream is NULL
  */
-int f0putc(int c, FILE * stream) {
+int f0putc(int c, FILE * stream)
+{
    int rc = 0;
    if (stream)
       rc = fputc(c, stream);
@@ -1508,7 +1307,8 @@ int f0putc(int c, FILE * stream) {
  *
  * @return   result of underlying fputs(), or 0 if stream is NULL
  */
-int f0puts(const char * msg, FILE * stream) {
+int f0puts(const char * msg, FILE * stream)
+{
    int rc = 0;
    if (stream)
       rc = fputs(msg, stream);
@@ -1524,7 +1324,8 @@ int f0puts(const char * msg, FILE * stream) {
  *
  * @return  result of underlying vfprintf(), or 0 if stream is NULL
  */
-int f0printf(FILE * stream, const char * format, ...) {
+int f0printf(FILE * stream, const char * format, ...)
+{
    int rc = 0;
    // printf("(%s) stream=%p\n", __func__, stream);
    if (stream) {
@@ -1546,7 +1347,8 @@ int f0printf(FILE * stream, const char * format, ...) {
  *
  * @return result of underlying vfprintf(), or 0 if stream is NULL
  */
-int vf0printf(FILE * stream, const char * format, va_list ap) {
+int vf0printf(FILE * stream, const char * format, va_list ap)
+{
    int rc = 0;
    if (stream)
       rc = vfprintf(stream, format, ap);
@@ -1564,7 +1366,8 @@ int vf0printf(FILE * stream, const char * format, va_list ap) {
  * @param bytect number of bytes
  * @return **true** if all bytes are zero, **false** if not
  */
-bool all_bytes_zero(Byte * bytes, int bytect) {
+bool all_bytes_zero(Byte * bytes, int bytect)
+{
    Byte sum = 0;
    for (int ndx=0; ndx < bytect; ndx++) {
       sum |= bytes[ndx];
@@ -1574,7 +1377,8 @@ bool all_bytes_zero(Byte * bytes, int bytect) {
 
 // Private version of strcasestr(), avoids needing to set _GNU_SOURCE
 
-char * ascii_strcasestr(const char * haystack, const char * needle) {
+char * ascii_strcasestr(const char * haystack, const char * needle)
+{
    char * result = NULL;
    if (haystack && needle) {
       char * uhaystack = g_ascii_strup(haystack, /*len=*/ -1);   // -1: null-terminated
@@ -1604,7 +1408,8 @@ char * ascii_strcasestr(const char * haystack, const char * needle) {
  *  @remark
  *  Consider converting ignore_case to a flags byte of options
  */
-bool apply_filter_terms(const char * text, char ** terms, bool ignore_case) {
+bool apply_filter_terms(const char * text, char ** terms, bool ignore_case)
+{
    assert(text);
    bool debug = false;
    bool result = true;
