@@ -208,9 +208,9 @@ is_smbus_device_summary(GPtrArray * summaries, char * sbusno) {
 #endif
 
 
-/** Gets the numbers of all non-SMBus I2C devices
+/** Gets the numbers of I2C devices
  *
- *  \param  include_ignorable_devices  if true, do not exclude SMBus devices
+ *  \param  include_ignorable_devices  if true, do not exclude SMBus and other ignorable devices
  *  \return sorted #Byte_Value_Array of I2C device numbers, caller is responsible for freeing
  */
 Byte_Value_Array
@@ -225,15 +225,13 @@ get_i2c_device_numbers_using_udev(bool include_ignorable_devices) {
    if (summaries) {
       for (int ndx = 0; ndx < summaries->len; ndx++) {
          Udev_Device_Summary * summary = g_ptr_array_index(summaries, ndx);
-         if ( !include_ignorable_devices && ignorable_i2c_device_sysfs_name(summary->sysattr_name) )
-            continue;
          int busno = udev_i2c_device_summary_busno(summary);
          assert(busno >= 0);
          assert(busno <= 127);
-         bva_append(bva, busno);
+         if ( include_ignorable_devices || !is_ignorable_i2c_device(busno) )
+            bva_append(bva, busno);
       }
       free_udev_device_summaries(summaries);
-      // g_ptr_array_free(summaries, true);
    }
 
    if (debug)
