@@ -1,7 +1,7 @@
 /* vcp_feature_set.h
  *
  * <copyright>
- * Copyright (C) 2014-2016 Sanford Rockowitz <rockowitz@minsoft.com>
+ * Copyright (C) 2014-2018 Sanford Rockowitz <rockowitz@minsoft.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -21,13 +21,21 @@
  * </endcopyright>
  */
 
+/** \f
+ *
+ */
+
 #ifndef VCP_FEATURE_SET_H_
 #define VCP_FEATURE_SET_H_
 
+#include "public/ddcutil_types.h"
+
+/** \cond */
 #include <glib.h>
 #include <stdbool.h>
 
 #include "util/coredefs.h"
+/** \endcond */
 
 #include "base/feature_sets.h"
 
@@ -41,7 +49,11 @@ typedef bool (*VCP_Feature_Set_Filter_Func)(VCP_Feature_Table_Entry * ventry);
 void free_vcp_feature_set(VCP_Feature_Set fset);
 
 VCP_Feature_Set
-create_feature_set(VCP_Feature_Subset subset, DDCA_MCCS_Version_Spec vcp_version);
+create_feature_set(
+      VCP_Feature_Subset     subset,
+      DDCA_MCCS_Version_Spec vcp_version,
+      Feature_Set_Flags      flags);
+   // bool                   exclude_table_features);
 
 VCP_Feature_Set
 create_single_feature_set_by_vcp_entry(VCP_Feature_Table_Entry * vcp_entry);
@@ -64,9 +76,11 @@ VCP_Feature_Set
 create_feature_set_from_feature_set_ref(
    Feature_Set_Ref *       fsref,
    DDCA_MCCS_Version_Spec  vcp_version,
-   bool                    force);
+   Feature_Set_Flags       flags);
+ //  bool                    force);
 
 void filter_feature_set(VCP_Feature_Set fset, VCP_Feature_Set_Filter_Func func);
 
+DDCA_Feature_List feature_list_from_feature_set(VCP_Feature_Set feature_set);
 
 #endif /* VCP_FEATURE_SET_H_ */
