@@ -50,7 +50,6 @@ char * vcp_value_type_name(DDCA_Vcp_Value_Type value_type) {
 }
 
 
-
 char * ddca_vcp_value_type_name(DDCA_Vcp_Value_Type  value_type) {
    char * result = "<unrecognized>";
    switch(value_type) {
@@ -69,14 +68,14 @@ char * ddca_vcp_value_type_name(DDCA_Vcp_Value_Type  value_type) {
 
 // TODO: MERGE dbgrpt_ddca_single_vcp_value(), report_single_vcp_value()
 
-void dbgrpt_ddca_single_vcp_value(
-      DDCA_Single_Vcp_Value * valrec,
-      int depth)
+void dbgrpt_single_vcp_value(
+      Single_Vcp_Value * valrec,
+      int                depth)
 {
    int d1 = depth + 1;
    int d2 = depth + 2;
 
-   rpt_vstring(depth, "DDCA_Single_Vcp_Value at %p:", valrec);
+   rpt_vstring(depth, "Single_Vcp_Value at %p:", valrec);
    if (valrec) {
       rpt_vstring(d1, "Opcode:          0x%02x", valrec->opcode);
       rpt_vstring(d1, "Value type       %d - %s", valrec->value_type, ddca_vcp_value_type_name(valrec->value_type));
@@ -97,15 +96,11 @@ void dbgrpt_ddca_single_vcp_value(
          rpt_vstring(d1, "sh:          0x%02x",  valrec->val.nc.sh);
          rpt_vstring(d1, "sl:          0x%02x",  valrec->val.nc.sl);
       }
-
    }
-
 }
 
 
-
-
-void report_single_vcp_value(DDCA_Single_Vcp_Value * valrec, int depth) {
+void report_single_vcp_value(Single_Vcp_Value * valrec, int depth) {
    int d1 = depth+1;
    rpt_vstring(depth, "Single_Vcp_Value at %p:", valrec);
    rpt_vstring(d1, "opcode=0x%02x, value_type=%s (0x%02x)",
@@ -130,7 +125,7 @@ void report_single_vcp_value(DDCA_Single_Vcp_Value * valrec, int depth) {
 #define SUMMARIZE_SINGLE_VCP_VALUE_BUFFER_SIZE  101
 // to expose an int rather than a define in the header file
 const int summzrize_single_vcp_value_buffer_size = SUMMARIZE_SINGLE_VCP_VALUE_BUFFER_SIZE;
-char * summarize_single_vcp_value_r(DDCA_Single_Vcp_Value * valrec, char * buffer, int bufsz) {
+char * summarize_single_vcp_value_r(Single_Vcp_Value * valrec, char * buffer, int bufsz) {
    bool debug = false;
    DBGMSF(debug, "Starting.  buffer=%p, bufsz=%d", buffer, bufsz);
    if (buffer) {
@@ -185,26 +180,29 @@ char * summarize_single_vcp_value_r(DDCA_Single_Vcp_Value * valrec, char * buffe
 }
 
 
-char * summarize_single_vcp_value(DDCA_Single_Vcp_Value * valrec) {
+char * summarize_single_vcp_value(Single_Vcp_Value * valrec) {
    static char buffer[SUMMARIZE_SINGLE_VCP_VALUE_BUFFER_SIZE];
    return summarize_single_vcp_value_r(valrec, buffer, sizeof(buffer));
 }
 
 // ignoring Buffer * since it only exists temporarily for transition
-void free_single_vcp_value(DDCA_Single_Vcp_Value * vcp_value) {
+void free_single_vcp_value(Single_Vcp_Value * vcp_value) {
+   bool debug = false;
+   DBGMSF(debug, "Starting. vcp_value=%s", summarize_single_vcp_value(vcp_value));
    if (vcp_value->value_type == DDCA_TABLE_VCP_VALUE) {
       if (vcp_value->val.t.bytes)
          free(vcp_value->val.t.bytes);
    }
    free(vcp_value);
+   DBGMSF(debug, "Done");
 }
 
 // wrap free_single_vcp_value() in signature of GDestroyNotify()
 void free_single_vcp_value_func(gpointer data) {
-   free_single_vcp_value((DDCA_Single_Vcp_Value *) data);
+   free_single_vcp_value((Single_Vcp_Value *) data);
 }
 
-DDCA_Single_Vcp_Value *
+Single_Vcp_Value *
 create_nontable_vcp_value(
       Byte feature_code,
       Byte mh,
@@ -212,7 +210,7 @@ create_nontable_vcp_value(
       Byte sh,
       Byte sl)
 {
-   DDCA_Single_Vcp_Value * valrec = calloc(1,sizeof(DDCA_Single_Vcp_Value));
+   Single_Vcp_Value * valrec = calloc(1,sizeof(Single_Vcp_Value));
    valrec->value_type = DDCA_NON_TABLE_VCP_VALUE;
    valrec->opcode = feature_code;
    valrec->val.nc.mh = mh;
@@ -225,13 +223,36 @@ create_nontable_vcp_value(
    return valrec;
 }
 
-DDCA_Single_Vcp_Value *
+#ifdef ALT
+DDCA_Any_Vcp_Value *
+create_nontable_vcp_value2(
+      Byte feature_code,
+      Byte mh,
+      Byte ml,
+      Byte sh,
+      Byte sl)
+{
+   DDCA_Any_Vcp_Value * valrec = calloc(1,sizeof(DDCA_Any_Vcp_Value));
+   valrec->value_type = DDCA_NON_TABLE_VCP_VALUE;
+   valrec->opcode = feature_code;
+   valrec->val.c_nc.mh = mh;
+   valrec->val.c_nc.ml = ml;
+   valrec->val.c_nc.sh = sh;
+   valrec->val.c_nc.sl = sl;
+   // not needed thanks to overlay
+   // valrec->val.nt.max_val = mh <<8 | ml;
+   // valrec->val.nt.cur_val = sh <<8 | sl;
+   return valrec;
+}
+#endif
+
+Single_Vcp_Value *
 create_cont_vcp_value(
       Byte feature_code,
       ushort max_val,
       ushort cur_val)
 {
-   DDCA_Single_Vcp_Value * valrec = calloc(1,sizeof(DDCA_Single_Vcp_Value));
+   Single_Vcp_Value * valrec = calloc(1,sizeof(Single_Vcp_Value));
    valrec->value_type = DDCA_NON_TABLE_VCP_VALUE;
    valrec->opcode = feature_code;
    // not needed thanks to overlay
@@ -244,13 +265,13 @@ create_cont_vcp_value(
    return valrec;
 }
 
-DDCA_Single_Vcp_Value *
+Single_Vcp_Value *
 create_table_vcp_value_by_bytes(
       Byte   feature_code,
       Byte * bytes,
       ushort bytect)
 {
-   DDCA_Single_Vcp_Value * valrec = calloc(1,sizeof(DDCA_Single_Vcp_Value));
+   Single_Vcp_Value * valrec = calloc(1,sizeof(Single_Vcp_Value));
    valrec->value_type = DDCA_TABLE_VCP_VALUE;
    valrec->opcode = feature_code;
    valrec->val.t.bytect = bytect;
@@ -259,19 +280,44 @@ create_table_vcp_value_by_bytes(
    return valrec;
 }
 
+#ifdef ALT
+DDCA_Any_Vcp_Value *
+create_table_vcp_value_by_bytes2(
+      Byte   feature_code,
+      Byte * bytes,
+      ushort bytect)
+{
+   DDCA_Any_Vcp_Value * valrec = calloc(1,sizeof(DDCA_Any_Vcp_Value));
+   valrec->value_type = DDCA_TABLE_VCP_VALUE;
+   valrec->opcode = feature_code;
+   valrec->val.t.bytect = bytect;
+   valrec->val.t.bytes = malloc(bytect);
+   memcpy(valrec->val.t.bytes, bytes, bytect);
+   return valrec;
+}
+#endif
 
-DDCA_Single_Vcp_Value *
+
+
+Single_Vcp_Value *
 create_table_vcp_value_by_buffer(Byte feature_code, Buffer * buffer) {
    return create_table_vcp_value_by_bytes(feature_code, buffer->bytes, buffer->len);
 }
 
+#ifdef ALT
+DDCA_Any_Vcp_Value *
+create_table_vcp_value_by_buffer2(Byte feature_code, Buffer * buffer) {
+   return create_table_vcp_value_by_bytes2(feature_code, buffer->bytes, buffer->len);
+}
+#endif
 
-DDCA_Single_Vcp_Value *
+
+Single_Vcp_Value *
 create_single_vcp_value_by_parsed_vcp_response(
       Byte feature_id,
       Parsed_Vcp_Response * presp)
 {
-   DDCA_Single_Vcp_Value * valrec = NULL;
+   Single_Vcp_Value * valrec = NULL;
 
    if (presp->response_type == DDCA_NON_TABLE_VCP_VALUE) {
       assert(presp->non_table_response->valid_response);
@@ -297,7 +343,7 @@ create_single_vcp_value_by_parsed_vcp_response(
 }
 
 // temp for aid in conversion
-Parsed_Vcp_Response * single_vcp_value_to_parsed_vcp_response(DDCA_Single_Vcp_Value * valrec) {
+Parsed_Vcp_Response * single_vcp_value_to_parsed_vcp_response(Single_Vcp_Value * valrec) {
    Parsed_Vcp_Response * presp = calloc(1, sizeof(Parsed_Vcp_Response));
    presp->response_type = valrec->value_type;
    if (valrec->value_type == DDCA_NON_TABLE_VCP_VALUE) {
@@ -322,7 +368,9 @@ Parsed_Vcp_Response * single_vcp_value_to_parsed_vcp_response(DDCA_Single_Vcp_Va
    return presp;
 }
 
-Nontable_Vcp_Value * single_vcp_value_to_nontable_vcp_value(DDCA_Single_Vcp_Value * valrec) {
+Nontable_Vcp_Value * single_vcp_value_to_nontable_vcp_value(Single_Vcp_Value * valrec) {
+   bool debug = false;
+   DBGMSF(debug, "Starting. valrec=%p", valrec);
    Nontable_Vcp_Value * non_table_response = calloc(1, sizeof(Nontable_Vcp_Value));
    assert (valrec->value_type == DDCA_NON_TABLE_VCP_VALUE);
 
@@ -334,16 +382,20 @@ Nontable_Vcp_Value * single_vcp_value_to_nontable_vcp_value(DDCA_Single_Vcp_Valu
    non_table_response->sl        = valrec->val.nc.sl;
    non_table_response->vcp_code  = valrec->opcode;
 
+   DBGMSF(debug, "Done. Returning: %p", non_table_response);
    return non_table_response;
 }
 
 
-/** Converts a #DDCA_Single_Vcp_Value to #DDCA_Any_Vcp_Value
+/** Converts a #Single_Vcp_Value to #DDCA_Any_Vcp_Value
  *
- *  \param  valrec  pointer to #DDCA_Single_Vcp_Value to convert
- *  \return converted value
+ *  \param  valrec  pointer to #Single_Vcp_Value to convert
+ *  \return newly allocated converted value
+ *
+ *  \remark
+ *  If table type, the bytes are copied
  */
-DDCA_Any_Vcp_Value * single_vcp_value_to_any_vcp_value(DDCA_Single_Vcp_Value * valrec) {
+DDCA_Any_Vcp_Value * single_vcp_value_to_any_vcp_value(Single_Vcp_Value * valrec) {
    DDCA_Any_Vcp_Value * anyval = calloc(1, sizeof(DDCA_Any_Vcp_Value));
    anyval->opcode     = valrec->opcode;
    anyval->value_type = valrec->value_type;
@@ -355,13 +407,41 @@ DDCA_Any_Vcp_Value * single_vcp_value_to_any_vcp_value(DDCA_Single_Vcp_Value * v
    }
    else {          // DDCA_TABLE_VCP_VALUE
       anyval->val.t.bytect = valrec->val.t.bytect;
-      anyval->val.t.bytes  = valrec->val.t.bytes;
+      if (valrec->val.t.bytect > 0 && valrec->val.t.bytes) {
+         anyval->val.t.bytes  = malloc(valrec->val.t.bytect);
+         memcpy(anyval->val.t.bytes, valrec->val.t.bytes, valrec->val.t.bytect);
+      }
    }
 
    return anyval;
 }
 
 
+/** Converts a #DDCA_Any_Vcp_Value to #Single_Vcp_Value
+ *
+ *  \param  valrec  pointer to #DDCA_Any_Vcp_Value to convert
+ *  \return newly allocated converted value
+ *
+ *  \remark
+ *  If table type, only the pointer to the bytes is copied
+ */
+Single_Vcp_Value * any_vcp_value_to_single_vcp_value(DDCA_Any_Vcp_Value * anyval) {
+   Single_Vcp_Value * valrec = calloc(1, sizeof(Single_Vcp_Value));
+   valrec->opcode     = anyval->opcode;
+   valrec->value_type = anyval->value_type;
+   if (valrec->value_type ==  DDCA_NON_TABLE_VCP_VALUE) {
+      valrec->val.nc.mh = anyval->val.c_nc.mh;
+      valrec->val.nc.ml = anyval->val.c_nc.ml;
+      valrec->val.nc.sh = anyval->val.c_nc.sh;
+      valrec->val.nc.sl = anyval->val.c_nc.sl;
+   }
+   else {          // DDCA_TABLE_VCP_VALUE
+      valrec->val.t.bytect = anyval->val.t.bytect;
+      valrec->val.t.bytes  = anyval->val.t.bytes;
+   }
+   return valrec;
+}
+
 
 Vcp_Value_Set vcp_value_set_new(int initial_size){
    GPtrArray* ga = g_ptr_array_sized_new(initial_size);
@@ -370,10 +450,11 @@ Vcp_Value_Set vcp_value_set_new(int initial_size){
 }
 
 void free_vcp_value_set(Vcp_Value_Set vset){
+   // DBGMSG("Executing.");
    g_ptr_array_free(vset, true);
 }
 
-void vcp_value_set_add(Vcp_Value_Set vset,  DDCA_Single_Vcp_Value * pval){
+void vcp_value_set_add(Vcp_Value_Set vset,  Single_Vcp_Value * pval){
    g_ptr_array_add(vset, pval);
 }
 
@@ -381,7 +462,7 @@ int vcp_value_set_size(Vcp_Value_Set vset){
    return vset->len;
 }
 
-DDCA_Single_Vcp_Value * vcp_value_set_get(Vcp_Value_Set vset, int ndx){
+Single_Vcp_Value * vcp_value_set_get(Vcp_Value_Set vset, int ndx){
    assert(0 <= ndx && ndx < vset->len);
    return g_ptr_array_index(vset, ndx);
 }
